@@ -2,7 +2,7 @@
 # Purpose : Cache Size Expiry Policy Class.
 # Author  : Sam Graham
 # Created : 25 Jun 2008
-# CVS     : $Id: Size.pm,v 1.6 2009-09-04 21:35:44 illusori Exp $
+# CVS     : $Id: Size.pm,v 1.8 2010-02-09 12:30:48 illusori Exp $
 ###############################################################################
 
 package Cache::CacheFactory::Expiry::Size;
@@ -20,7 +20,7 @@ use Cache::CacheFactory::Expiry::Base;
 
 use base qw/Cache::CacheFactory::Expiry::Base/;
 
-$Cache::CacheFactory::Expiry::Size::VERSION = sprintf"%d.%03d", q$Revision: 1.6 $ =~ /: (\d+)\.(\d+)/;
+$Cache::CacheFactory::Expiry::Size::VERSION = '1.09_01';
 
 @Cache::CacheFactory::Expiry::Size::EXPORT_OK = qw/$NO_MAX_SIZE/;
 
@@ -172,19 +172,8 @@ sub should_keep
             if exists $self->{ _cache_size };
     }
 
-if( $ENV{ VERBOSE_CACHEFACTORY_DIAG } )
-{
-  eval "use Test::More";
-  diag( "should_keep: cachesize = $cachesize, maxsize = " . $self->{ max_size } . ", itemsize = $itemsize." );
-}
-
     return( 1 ) if $cachesize <= $self->{ max_size };
 
-if( $ENV{ VERBOSE_CACHEFACTORY_DIAG } )
-{
-  diag( "  not keeping." );
-}
-
     #  We're assuming that a remove will be triggered and succeed
     #  this is potentially risky, but probably ok.
     $self->{ _cache_size } -= $itemsize if exists $self->{ _cache_size };
@@ -217,11 +206,6 @@ sub pre_purge_per_storage_hook
             $storage->isa( 'Cache::MemoryCache' ) )
         {
             $self->{ _cache_size } = $self->overrule_size( $storage );
-if( $ENV{ VERBOSE_CACHEFACTORY_DIAG } )
-{
-  eval "use Test::More";
-  diag( "pre_purge_per_storage_hook: overrule_size() = " . $self->{ _cache_size } );
-}
         }
         else
         {
@@ -236,11 +220,6 @@ sub post_purge_per_storage_hook
 {
     my ( $self, $cache, $storage ) = @_;
 
-if( $ENV{ VERBOSE_CACHEFACTORY_DIAG } )
-{
-  eval "use Test::More";
-  diag( "pre_purge_per_storage_hook: size after purge = " . $self->{ _cache_size } );
-}
     #  Clear our local caching of the cache size.
     delete $self->{ _cache_size };
     $self->SUPER::post_purge_per_storage_hook( $cache, $storage );
@@ -484,7 +463,7 @@ Last author:     $Author: illusori $
 
 =head1 COPYRIGHT
 
-Copyright 2008 Sam Graham.
+Copyright 2008-2010 Sam Graham.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
