@@ -2,7 +2,7 @@
 # Purpose : Cache Storage Policy Factory.
 # Author  : Sam Graham
 # Created : 23 Jun 2008
-# CVS     : $Id: Storage.pm,v 1.5 2008-07-07 22:05:45 illusori Exp $
+# CVS     : $Id: Storage.pm,v 1.8 2010-02-09 12:30:58 illusori Exp $
 ###############################################################################
 
 package Cache::CacheFactory::Storage;
@@ -14,7 +14,7 @@ use Class::Factory;
 
 use base qw/Class::Factory/;
 
-$Cache::CacheFactory::Storage::VERSION = sprintf"%d.%03d", q$Revision: 1.5 $ =~ /: (\d+)\.(\d+)/;
+$Cache::CacheFactory::Storage::VERSION = '1.09_01';
 
 sub new
 {
@@ -34,6 +34,8 @@ __PACKAGE__->register_factory_type(
     file         => 'Cache::FileCache' );
 __PACKAGE__->register_factory_type(
     null         => 'Cache::NullCache' );
+__PACKAGE__->register_factory_type(
+    fastmemory   => 'Cache::FastMemoryCache' );
 
 1;
 
@@ -43,7 +45,7 @@ __END__
 
 =head1 NAME
 
-Cache::CacheFactory::Storage - factory class for storage policies for Cache::CacheFactory.
+Cache::CacheFactory::Storage - Factory class for storage policies for Cache::CacheFactory.
 
 =head1 DESCRIPTION
 
@@ -77,7 +79,7 @@ Last author:     $Author: illusori $
 
 =head1 COPYRIGHT
 
-Copyright 2008 Sam Graham.
+Copyright 2008-2010 Sam Graham.
 
 This library is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
